#!/usr/bin/env python

"""
Program code and data representations.

Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

class Context:

    """
    A representation of a context used in a program, providing the special
    context value types.
    """

    def __init__(self, truth_value, repr):
        self.truth_value = truth_value
        self.repr = repr

    def __repr__(self):
        return self.repr

    def __nonzero__(self):
        return self.truth_value

    __shortrepr__ = __repr__

# A representation of a context that is replaced upon certain assignment
# operations.

ReplaceableContext = Context(0, "Replace")

# A representation of a context that is employed by classes so that
# instantiators have enough slots in the invocation frame, yet does not cause
# testing of the context or adjustment of the frame.

PlaceholderContext = Context(0, "Placeholder")

# vim: tabstop=4 expandtab shiftwidth=4
